changeset 2251:d2729e1aaa6e

Rename for clarity
author Gary Benson <gbenson@redhat.com>
date Tue, 01 Mar 2011 11:29:45 +0000
parents 5395e0f191fe
children a8faa91173e7
files src/cpu/zero/vm/cppInterpreter_zero.cpp src/cpu/zero/vm/cppInterpreter_zero.hpp
diffstat 2 files changed, 6 insertions(+), 6 deletions(-) [+]
line wrap: on
line diff
--- a/src/cpu/zero/vm/cppInterpreter_zero.hpp	Tue Mar 01 11:21:20 2011 +0000
+++ b/src/cpu/zero/vm/cppInterpreter_zero.hpp	Tue Mar 01 11:29:45 2011 +0000
@@ -45,7 +45,7 @@
  private:
   // Helpers for method_handle_entry
   static void process_method_handle(oop method_handle, TRAPS);
-  static void insert_vmslots(int first_slot, int num_slots, TRAPS);
+  static void insert_vmslots(int insert_before, int num_slots, TRAPS);
   static void remove_vmslots(int first_slot, int num_slots, TRAPS);
   static BasicType result_type_of_handle(oop method_handle);
 #ifdef ASSERT
--- a/src/cpu/zero/vm/cppInterpreter_zero.cpp	Tue Mar 01 11:21:20 2011 +0000
+++ b/src/cpu/zero/vm/cppInterpreter_zero.cpp	Tue Mar 01 11:29:45 2011 +0000
@@ -946,10 +946,10 @@
   }
 }
 
-// The new slots will be inserted _before_ first slot.
-// Slots < first_slot will have the same slot number after the insert.
-// Slots >= first_slot will become old_slot + num_slots.
-void CppInterpreter::insert_vmslots(int first_slot, int num_slots, TRAPS) {
+// The new slots will be inserted before slot insert_before.
+// Slots < insert_before will have the same slot number after the insert.
+// Slots >= insert_before will become old_slot + num_slots.
+void CppInterpreter::insert_vmslots(int insert_before, int num_slots, TRAPS) {
   JavaThread *thread = (JavaThread *) THREAD;
   ZeroStack *stack = thread->zero_stack();
 
@@ -959,7 +959,7 @@
   intptr_t *vmslots = stack->sp();
 
   // Shuffle everything up
-  for (int i = 0; i < first_slot; i++)
+  for (int i = 0; i < insert_before; i++)
     SET_VMSLOTS_SLOT(VMSLOTS_SLOT(i + num_slots), i);
 }
 